==> haskell-some-1.0.5-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.5
visibility:           public
id:                   some-1.0.5-36xIADGNqiWGv9lC459cQD
key:                  some-1.0.5-36xIADGNqiWGv9lC459cQD
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  13cee31e3a5dd89aea9f1a327a061375
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/some-1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/some-1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/some-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.5-36xIADGNqiWGv9lC459cQD
depends:              base-4.17.2.1 deepseq-1.4.8.0
haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-some-1.0.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-some.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 some
version:              1.0.6
visibility:           public
id:                   some-1.0.6-ABySMdca8h36lZn3WY36IC
key:                  some-1.0.6-ABySMdca8h36lZn3WY36IC
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    James Cook <mokus@deepbondi.net>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/some
synopsis:             Existential type: Some
description:
    This library defines an existential type '\''Some'\''.

    @
    data Some f where
    \    Some :: f a -> Some f
    @

    in few variants, and utilities to work with it.

    If you are unsure which variant to use, use the one in "Data.Some" module.

category:             Data, Dependent Types
abi:                  472ec3c45b06c9d316a89e9dd240d03f
exposed:              True
exposed-modules:
    Data.EqP Data.GADT.Compare Data.GADT.DeepSeq Data.GADT.Show
    Data.OrdP Data.Some Data.Some.Church Data.Some.GADT
    Data.Some.Newtype

hidden-modules:       Data.GADT.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/some-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/some-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-some
hs-libraries:         HSsome-1.0.6-ABySMdca8h36lZn3WY36IC
depends:
    base-4.17.2.1 base-orphans-0.9.1-H7Oi1FO5RM5r3PyYaGxEl
    deepseq-1.4.8.0

haddock-interfaces:   /usr/share/doc/haskell-some/html/some.haddock
haddock-html:         /usr/share/doc/haskell-some/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
